@@ -11,21 +11,13 @@
 # limitations under the License.
 
 """A test suite that runs all tests for pyfakefs at once.
-Excludes tests using external pathlib2 and scandir packages."""
+Excludes tests using external scandir package."""
 
 import sys
 import unittest
 
 from pyfakefs import extra_packages
 
-if extra_packages.pathlib2:
-    extra_packages.pathlib2 = None
-    try:
-        import pathlib
-    except ImportError:
-        pathlib = None
-    extra_packages.pathlib = pathlib
-
 if extra_packages.use_scandir_package:
     extra_packages.use_scandir_package = False
     try:
@@ -37,6 +29,6 @@ if extra_packages.use_scandir_package:
 
 from pyfakefs.tests.all_tests import AllTests  # noqa: E402
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     result = unittest.TextTestRunner(verbosity=2).run(AllTests().suite())
     sys.exit(int(not result.wasSuccessful()))
